diff dsp/tempotracking/TempoTrackV2.h @ 104:1e433aaa44ad

Merge mepd_new_params branch
author Chris Cannam
date Mon, 02 Sep 2013 09:26:46 +0100
parents d7619173d43c
children fe7552b4f80a
line wrap: on
line diff
--- a/dsp/tempotracking/TempoTrackV2.h	Thu Jun 13 10:23:09 2013 +0100
+++ b/dsp/tempotracking/TempoTrackV2.h	Mon Sep 02 09:26:46 2013 +0100
@@ -18,16 +18,14 @@
 #define TEMPOTRACKV2_H
 
 #include <vector>
-#include <cstddef>
-
-using std::vector;
+using namespace std;
 
 //!!! Question: how far is this actually sample rate dependent?  I
 // think it does produce plausible results for e.g. 48000 as well as
 // 44100, but surely the fixed window sizes and comb filtering will
 // make it prefer double or half time when run at e.g. 96000?
 
-class TempoTrackV2  
+class TempoTrackV2
 {
 public:
     /**
@@ -41,15 +39,17 @@
     TempoTrackV2(float sampleRate, size_t dfIncrement);
     ~TempoTrackV2();
 
     // Returned beat periods are given in df increment units; tempi in bpm
     void calculateBeatPeriod(const vector<double> &df,
                              vector<double> &beatPeriod,
-                             vector<double> &tempi);
+                             vector<double> &tempi, double inputtempo, bool constraintempo);
 
     // Returned beat positions are given in df increment units
+    // MEPD 28/11/12 Expose alpha and tightness parameters
     void calculateBeats(const vector<double> &df,
                         const vector<double> &beatPeriod,
-                        vector<double> &beats);
+                        vector<double> &beats, double alpha, double tightness);
 
 private:
     typedef vector<int> i_vec_t;
@@ -41,15 +39,17 @@
     ~TempoTrackV2();
 
-    // Returned beat periods are given in df increment units; tempi in bpm
+    // Returned beat periods are given in df increment units; inputtempo and tempi in bpm
+    // MEPD 28/11/12 Expose inputtempo and constraintempo parameters
     void calculateBeatPeriod(const vector<double> &df,
                              vector<double> &beatPeriod,